@@ -3,8 +3,8 @@
 /**
  * @file api/v1/_submissions/BackendSubmissionsHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class BackendSubmissionsHandler
@@ -45,6 +45,16 @@ class BackendSubmissionsHandler extends PKPBackendSubmissionsHandler {
 					),
 				),
 			),
+			'PUT' => [
+				[
+					'pattern' => "{$rootPattern}/addToCatalog",
+					'handler' => [$this, 'addToCatalog'],
+					'roles' => [
+						ROLE_ID_SITE_ADMIN,
+						ROLE_ID_MANAGER,
+					],
+				],
+			],
 		);
 		parent::__construct();
 	}
@@ -182,4 +192,53 @@ class BackendSubmissionsHandler extends PKPBackendSubmissionsHandler {
 
 		return $response->withJson(true);
 	}
+
+	/**
+	 * Add one or more submissions to the catalog
+	 *
+	 * @param $slimRequest Request Slim request object
+	 * @param $response Response object
+	 *
+	 * @return Response
+	 */
+	public function addToCatalog($slimRequest, $response, $args) {
+		$params = $slimRequest->getParsedBody();
+
+		if (empty($params['submissionIds'])) {
+			return $response->withStatus(400)->withJsonError('api.submissions.400.submissionIdsRequired');
+		}
+
+		$submissionIds = array_map('intval', (array) $params['submissionIds']);
+
+		if (empty($submissionIds)) {
+			return $response->withStatus(400)->withJsonError('api.submissions.400.submissionIdsRequired');
+		}
+
+
+		$primaryLocale = $this->getRequest()->getContext()->getPrimaryLocale();
+		$allowedLocales = $this->getRequest()->getContext()->getSupportedFormLocales();
+
+		$validPublications = [];
+		foreach ($submissionIds as $submissionId) {
+			$submission = Services::get('submission')->get($submissionId);
+			if (!$submission) {
+				return $response->withStatus(400)->withJsonError('api.submissions.400.submissionsNotFound');
+			}
+			$publication = $submission->getCurrentPublication();
+			if ($publication->getData('status') === STATUS_PUBLISHED) {
+				continue;
+			}
+			$errors = Services::get('publication')->validatePublish($publication, $submission, $allowedLocales, $primaryLocale);
+			if (!empty($errors)) {
+				return $response->withStatus(400)->withJson($errors);
+			}
+			$validPublications[] = $publication;
+		}
+
+		foreach($validPublications as $validPublication) {
+			Services::get('publication')->publish($validPublication);
+		}
+
+		return $response->withJson(true);
+	}
 }
