@@ -40,10 +40,11 @@ class Publication extends PKPPublication {
 	 * Get the URL to a localized cover image
 	 *
 	 * @param int $contextId
+	 * @param string $preferredLocale Return the cover image in a specified locale.
 	 * @return string
 	 */
-	public function getLocalizedCoverImageUrl($contextId) {
-		$coverImage = $this->getLocalizedData('coverImage');
+	public function getLocalizedCoverImageUrl($contextId, $preferredLocale = null) {
+		$coverImage = $this->getLocalizedData('coverImage', $preferredLocale);
 
 		if (!$coverImage) {
 			return Application::get()->getRequest()->getBaseUrl() . '/templates/images/book-default.png';
@@ -73,4 +74,4 @@ class Publication extends PKPPublication {
 			Services::get('publication')->getThumbnailFilename($pathParts['basename']),
 		]);
 	}
-}
\ No newline at end of file
+}
