@@ -2,8 +2,8 @@
 /**
  * @file classes/services/StatsService.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class PKPStatsService
@@ -19,8 +19,8 @@ class StatsService extends \PKP\Services\PKPStatsService {
 	 *
 	 * @param array $args
 	 */
-	protected function _getQueryBuilder($args = []) {
-		$statsQB = parent::_getQueryBuilder($args);
+	protected function getQueryBuilder($args = []) {
+		$statsQB = parent::getQueryBuilder($args);
 		if (!empty(($args['seriesIds']))) {
 			$statsQB->filterBySections($args['seriesIds']);
 		}
